# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/errors/campaign_group_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/errors/campaign_group_error.proto',
  package='google.ads.googleads.v0.errors',
  syntax='proto3',
  serialized_pb=_b('\n?google/ads/googleads_v0/proto/errors/campaign_group_error.proto\x12\x1egoogle.ads.googleads.v0.errors\"\xce\x01\n\x16\x43\x61mpaignGroupErrorEnum\"\xb3\x01\n\x12\x43\x61mpaignGroupError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x41\n=CANNOT_REMOVE_CAMPAIGN_GROUP_WITH_ENABLED_OR_PAUSED_CAMPAIGNS\x10\x02\x12\x12\n\x0e\x44UPLICATE_NAME\x10\x03\x12(\n$CANNOT_MODIFY_REMOVED_CAMPAIGN_GROUP\x10\x04\x42\xcd\x01\n\"com.google.ads.googleads.v0.errorsB\x17\x43\x61mpaignGroupErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v0/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V0.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V0\\Errorsb\x06proto3')
)



_CAMPAIGNGROUPERRORENUM_CAMPAIGNGROUPERROR = _descriptor.EnumDescriptor(
  name='CampaignGroupError',
  full_name='google.ads.googleads.v0.errors.CampaignGroupErrorEnum.CampaignGroupError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_REMOVE_CAMPAIGN_GROUP_WITH_ENABLED_OR_PAUSED_CAMPAIGNS', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DUPLICATE_NAME', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_MODIFY_REMOVED_CAMPAIGN_GROUP', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=127,
  serialized_end=306,
)
_sym_db.RegisterEnumDescriptor(_CAMPAIGNGROUPERRORENUM_CAMPAIGNGROUPERROR)


_CAMPAIGNGROUPERRORENUM = _descriptor.Descriptor(
  name='CampaignGroupErrorEnum',
  full_name='google.ads.googleads.v0.errors.CampaignGroupErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CAMPAIGNGROUPERRORENUM_CAMPAIGNGROUPERROR,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=100,
  serialized_end=306,
)

_CAMPAIGNGROUPERRORENUM_CAMPAIGNGROUPERROR.containing_type = _CAMPAIGNGROUPERRORENUM
DESCRIPTOR.message_types_by_name['CampaignGroupErrorEnum'] = _CAMPAIGNGROUPERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CampaignGroupErrorEnum = _reflection.GeneratedProtocolMessageType('CampaignGroupErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _CAMPAIGNGROUPERRORENUM,
  __module__ = 'google.ads.google_ads.v0.proto.errors.campaign_group_error_pb2'
  ,
  __doc__ = """Container for enum describing possible campaign group errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.errors.CampaignGroupErrorEnum)
  ))
_sym_db.RegisterMessage(CampaignGroupErrorEnum)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\"com.google.ads.googleads.v0.errorsB\027CampaignGroupErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v0/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V0.Errors\312\002\036Google\\Ads\\GoogleAds\\V0\\Errors'))
# @@protoc_insertion_point(module_scope)
