# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/resources/campaign_group.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.enums import campaign_group_status_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_campaign__group__status__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/resources/campaign_group.proto',
  package='google.ads.googleads.v0.resources',
  syntax='proto3',
  serialized_pb=_b('\n<google/ads/googleads_v0/proto/resources/campaign_group.proto\x12!google.ads.googleads.v0.resources\x1a?google/ads/googleads_v0/proto/enums/campaign_group_status.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xd7\x01\n\rCampaignGroup\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\'\n\x02id\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12*\n\x04name\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12Z\n\x06status\x18\x05 \x01(\x0e\x32J.google.ads.googleads.v0.enums.CampaignGroupStatusEnum.CampaignGroupStatusB\xd7\x01\n%com.google.ads.googleads.v0.resourcesB\x12\x43\x61mpaignGroupProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v0/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V0.Resources\xca\x02!Google\\Ads\\GoogleAds\\V0\\Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_campaign__group__status__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])




_CAMPAIGNGROUP = _descriptor.Descriptor(
  name='CampaignGroup',
  full_name='google.ads.googleads.v0.resources.CampaignGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.resources.CampaignGroup.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v0.resources.CampaignGroup.id', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v0.resources.CampaignGroup.name', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.ads.googleads.v0.resources.CampaignGroup.status', index=3,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=197,
  serialized_end=412,
)

_CAMPAIGNGROUP.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CAMPAIGNGROUP.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGNGROUP.fields_by_name['status'].enum_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_campaign__group__status__pb2._CAMPAIGNGROUPSTATUSENUM_CAMPAIGNGROUPSTATUS
DESCRIPTOR.message_types_by_name['CampaignGroup'] = _CAMPAIGNGROUP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CampaignGroup = _reflection.GeneratedProtocolMessageType('CampaignGroup', (_message.Message,), dict(
  DESCRIPTOR = _CAMPAIGNGROUP,
  __module__ = 'google.ads.google_ads.v0.proto.resources.campaign_group_pb2'
  ,
  __doc__ = """A campaign group.
  
  
  Attributes:
      resource_name:
          The resource name of the campaign group. Campaign group
          resource names have the form:
          ``customers/{customer_id}/campaignGroups/{campaign_group_id}``
      id:
          The ID of the campaign group.
      name:
          The name of the campaign group.  This field is required and
          should not be empty when creating new campaign groups.  It
          must not contain any null (code point 0x0), NL line feed (code
          point 0xA) or carriage return (code point 0xD) characters.
      status:
          The status of the campaign group.  When a new campaign group
          is added, the status defaults to ENABLED.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.resources.CampaignGroup)
  ))
_sym_db.RegisterMessage(CampaignGroup)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n%com.google.ads.googleads.v0.resourcesB\022CampaignGroupProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v0/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V0.Resources\312\002!Google\\Ads\\GoogleAds\\V0\\Resources'))
# @@protoc_insertion_point(module_scope)
