# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/services/keyword_plan_ad_group_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.resources import keyword_plan_ad_group_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_keyword__plan__ad__group__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/services/keyword_plan_ad_group_service.proto',
  package='google.ads.googleads.v0.services',
  syntax='proto3',
  serialized_pb=_b('\nJgoogle/ads/googleads_v0/proto/services/keyword_plan_ad_group_service.proto\x12 google.ads.googleads.v0.services\x1a\x43google/ads/googleads_v0/proto/resources/keyword_plan_ad_group.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\"5\n\x1cGetKeywordPlanAdGroupRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\x8a\x01\n MutateKeywordPlanAdGroupsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12Q\n\noperations\x18\x02 \x03(\x0b\x32=.google.ads.googleads.v0.services.KeywordPlanAdGroupOperation\"\xff\x01\n\x1bKeywordPlanAdGroupOperation\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12G\n\x06\x63reate\x18\x01 \x01(\x0b\x32\x35.google.ads.googleads.v0.resources.KeywordPlanAdGroupH\x00\x12G\n\x06update\x18\x02 \x01(\x0b\x32\x35.google.ads.googleads.v0.resources.KeywordPlanAdGroupH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"v\n!MutateKeywordPlanAdGroupsResponse\x12Q\n\x07results\x18\x02 \x03(\x0b\x32@.google.ads.googleads.v0.services.MutateKeywordPlanAdGroupResult\"7\n\x1eMutateKeywordPlanAdGroupResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xd7\x03\n\x19KeywordPlanAdGroupService\x12\xcd\x01\n\x15GetKeywordPlanAdGroup\x12>.google.ads.googleads.v0.services.GetKeywordPlanAdGroupRequest\x1a\x35.google.ads.googleads.v0.resources.KeywordPlanAdGroup\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/v0/{resource_name=customers/*/keywordPlanAdGroups/*}\x12\xe9\x01\n\x19MutateKeywordPlanAdGroups\x12\x42.google.ads.googleads.v0.services.MutateKeywordPlanAdGroupsRequest\x1a\x43.google.ads.googleads.v0.services.MutateKeywordPlanAdGroupsResponse\"C\x82\xd3\xe4\x93\x02=\"8/v0/customers/{customer_id=*}/keywordPlanAdGroups:mutate:\x01*B\xde\x01\n$com.google.ads.googleads.v0.servicesB\x1eKeywordPlanAdGroupServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V0.Services\xca\x02 Google\\Ads\\GoogleAds\\V0\\Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_keyword__plan__ad__group__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,])




_GETKEYWORDPLANADGROUPREQUEST = _descriptor.Descriptor(
  name='GetKeywordPlanAdGroupRequest',
  full_name='google.ads.googleads.v0.services.GetKeywordPlanAdGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.GetKeywordPlanAdGroupRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=245,
  serialized_end=298,
)


_MUTATEKEYWORDPLANADGROUPSREQUEST = _descriptor.Descriptor(
  name='MutateKeywordPlanAdGroupsRequest',
  full_name='google.ads.googleads.v0.services.MutateKeywordPlanAdGroupsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v0.services.MutateKeywordPlanAdGroupsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v0.services.MutateKeywordPlanAdGroupsRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=301,
  serialized_end=439,
)


_KEYWORDPLANADGROUPOPERATION = _descriptor.Descriptor(
  name='KeywordPlanAdGroupOperation',
  full_name='google.ads.googleads.v0.services.KeywordPlanAdGroupOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v0.services.KeywordPlanAdGroupOperation.update_mask', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v0.services.KeywordPlanAdGroupOperation.create', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v0.services.KeywordPlanAdGroupOperation.update', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v0.services.KeywordPlanAdGroupOperation.remove', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v0.services.KeywordPlanAdGroupOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=442,
  serialized_end=697,
)


_MUTATEKEYWORDPLANADGROUPSRESPONSE = _descriptor.Descriptor(
  name='MutateKeywordPlanAdGroupsResponse',
  full_name='google.ads.googleads.v0.services.MutateKeywordPlanAdGroupsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v0.services.MutateKeywordPlanAdGroupsResponse.results', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=699,
  serialized_end=817,
)


_MUTATEKEYWORDPLANADGROUPRESULT = _descriptor.Descriptor(
  name='MutateKeywordPlanAdGroupResult',
  full_name='google.ads.googleads.v0.services.MutateKeywordPlanAdGroupResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.MutateKeywordPlanAdGroupResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=819,
  serialized_end=874,
)

_MUTATEKEYWORDPLANADGROUPSREQUEST.fields_by_name['operations'].message_type = _KEYWORDPLANADGROUPOPERATION
_KEYWORDPLANADGROUPOPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_KEYWORDPLANADGROUPOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_keyword__plan__ad__group__pb2._KEYWORDPLANADGROUP
_KEYWORDPLANADGROUPOPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_keyword__plan__ad__group__pb2._KEYWORDPLANADGROUP
_KEYWORDPLANADGROUPOPERATION.oneofs_by_name['operation'].fields.append(
  _KEYWORDPLANADGROUPOPERATION.fields_by_name['create'])
_KEYWORDPLANADGROUPOPERATION.fields_by_name['create'].containing_oneof = _KEYWORDPLANADGROUPOPERATION.oneofs_by_name['operation']
_KEYWORDPLANADGROUPOPERATION.oneofs_by_name['operation'].fields.append(
  _KEYWORDPLANADGROUPOPERATION.fields_by_name['update'])
_KEYWORDPLANADGROUPOPERATION.fields_by_name['update'].containing_oneof = _KEYWORDPLANADGROUPOPERATION.oneofs_by_name['operation']
_KEYWORDPLANADGROUPOPERATION.oneofs_by_name['operation'].fields.append(
  _KEYWORDPLANADGROUPOPERATION.fields_by_name['remove'])
_KEYWORDPLANADGROUPOPERATION.fields_by_name['remove'].containing_oneof = _KEYWORDPLANADGROUPOPERATION.oneofs_by_name['operation']
_MUTATEKEYWORDPLANADGROUPSRESPONSE.fields_by_name['results'].message_type = _MUTATEKEYWORDPLANADGROUPRESULT
DESCRIPTOR.message_types_by_name['GetKeywordPlanAdGroupRequest'] = _GETKEYWORDPLANADGROUPREQUEST
DESCRIPTOR.message_types_by_name['MutateKeywordPlanAdGroupsRequest'] = _MUTATEKEYWORDPLANADGROUPSREQUEST
DESCRIPTOR.message_types_by_name['KeywordPlanAdGroupOperation'] = _KEYWORDPLANADGROUPOPERATION
DESCRIPTOR.message_types_by_name['MutateKeywordPlanAdGroupsResponse'] = _MUTATEKEYWORDPLANADGROUPSRESPONSE
DESCRIPTOR.message_types_by_name['MutateKeywordPlanAdGroupResult'] = _MUTATEKEYWORDPLANADGROUPRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetKeywordPlanAdGroupRequest = _reflection.GeneratedProtocolMessageType('GetKeywordPlanAdGroupRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETKEYWORDPLANADGROUPREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.keyword_plan_ad_group_service_pb2'
  ,
  __doc__ = """Request message for
  [KeywordPlanAdGroupService.GetKeywordPlanAdGroup][google.ads.googleads.v0.services.KeywordPlanAdGroupService.GetKeywordPlanAdGroup].
  
  
  Attributes:
      resource_name:
          The resource name of the Keyword Plan ad group to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.GetKeywordPlanAdGroupRequest)
  ))
_sym_db.RegisterMessage(GetKeywordPlanAdGroupRequest)

MutateKeywordPlanAdGroupsRequest = _reflection.GeneratedProtocolMessageType('MutateKeywordPlanAdGroupsRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEKEYWORDPLANADGROUPSREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.keyword_plan_ad_group_service_pb2'
  ,
  __doc__ = """Request message for
  [KeywordPlanAdGroupService.MutateKeywordPlanAdGroups][google.ads.googleads.v0.services.KeywordPlanAdGroupService.MutateKeywordPlanAdGroups].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose Keyword Plan ad groups are being
          modified.
      operations:
          The list of operations to perform on individual Keyword Plan
          ad groups.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateKeywordPlanAdGroupsRequest)
  ))
_sym_db.RegisterMessage(MutateKeywordPlanAdGroupsRequest)

KeywordPlanAdGroupOperation = _reflection.GeneratedProtocolMessageType('KeywordPlanAdGroupOperation', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDPLANADGROUPOPERATION,
  __module__ = 'google.ads.google_ads.v0.proto.services.keyword_plan_ad_group_service_pb2'
  ,
  __doc__ = """A single operation (create, update, remove) on a Keyword Plan ad group.
  
  
  Attributes:
      update_mask:
          The FieldMask that determines which resource fields are
          modified in an update.
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          Keyword Plan ad group.
      update:
          Update operation: The Keyword Plan ad group is expected to
          have a valid resource name.
      remove:
          Remove operation: A resource name for the removed Keyword Plan
          ad group is expected, in this format:  ``customers/{customer_i
          d}/keywordPlanAdGroups/{kp_ad_group_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.KeywordPlanAdGroupOperation)
  ))
_sym_db.RegisterMessage(KeywordPlanAdGroupOperation)

MutateKeywordPlanAdGroupsResponse = _reflection.GeneratedProtocolMessageType('MutateKeywordPlanAdGroupsResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEKEYWORDPLANADGROUPSRESPONSE,
  __module__ = 'google.ads.google_ads.v0.proto.services.keyword_plan_ad_group_service_pb2'
  ,
  __doc__ = """Response message for a Keyword Plan ad group mutate.
  
  
  Attributes:
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateKeywordPlanAdGroupsResponse)
  ))
_sym_db.RegisterMessage(MutateKeywordPlanAdGroupsResponse)

MutateKeywordPlanAdGroupResult = _reflection.GeneratedProtocolMessageType('MutateKeywordPlanAdGroupResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEKEYWORDPLANADGROUPRESULT,
  __module__ = 'google.ads.google_ads.v0.proto.services.keyword_plan_ad_group_service_pb2'
  ,
  __doc__ = """The result for the Keyword Plan ad group mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateKeywordPlanAdGroupResult)
  ))
_sym_db.RegisterMessage(MutateKeywordPlanAdGroupResult)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n$com.google.ads.googleads.v0.servicesB\036KeywordPlanAdGroupServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V0.Services\312\002 Google\\Ads\\GoogleAds\\V0\\Services'))

_KEYWORDPLANADGROUPSERVICE = _descriptor.ServiceDescriptor(
  name='KeywordPlanAdGroupService',
  full_name='google.ads.googleads.v0.services.KeywordPlanAdGroupService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=877,
  serialized_end=1348,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetKeywordPlanAdGroup',
    full_name='google.ads.googleads.v0.services.KeywordPlanAdGroupService.GetKeywordPlanAdGroup',
    index=0,
    containing_service=None,
    input_type=_GETKEYWORDPLANADGROUPREQUEST,
    output_type=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_keyword__plan__ad__group__pb2._KEYWORDPLANADGROUP,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0027\0225/v0/{resource_name=customers/*/keywordPlanAdGroups/*}')),
  ),
  _descriptor.MethodDescriptor(
    name='MutateKeywordPlanAdGroups',
    full_name='google.ads.googleads.v0.services.KeywordPlanAdGroupService.MutateKeywordPlanAdGroups',
    index=1,
    containing_service=None,
    input_type=_MUTATEKEYWORDPLANADGROUPSREQUEST,
    output_type=_MUTATEKEYWORDPLANADGROUPSRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002=\"8/v0/customers/{customer_id=*}/keywordPlanAdGroups:mutate:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_KEYWORDPLANADGROUPSERVICE)

DESCRIPTOR.services_by_name['KeywordPlanAdGroupService'] = _KEYWORDPLANADGROUPSERVICE

# @@protoc_insertion_point(module_scope)
