# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/enums/criterion_category_channel_availability_mode.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/enums/criterion_category_channel_availability_mode.proto',
  package='google.ads.googleads.v0.enums',
  syntax='proto3',
  serialized_pb=_b('\nVgoogle/ads/googleads_v0/proto/enums/criterion_category_channel_availability_mode.proto\x12\x1dgoogle.ads.googleads.v0.enums\"\xd4\x01\n,CriterionCategoryChannelAvailabilityModeEnum\"\xa3\x01\n(CriterionCategoryChannelAvailabilityMode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x10\n\x0c\x41LL_CHANNELS\x10\x02\x12!\n\x1d\x43HANNEL_TYPE_AND_ALL_SUBTYPES\x10\x03\x12$\n CHANNEL_TYPE_AND_SUBSET_SUBTYPES\x10\x04\x42\xde\x01\n!com.google.ads.googleads.v0.enumsB-CriterionCategoryChannelAvailabilityModeProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v0/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V0.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V0\\Enumsb\x06proto3')
)



_CRITERIONCATEGORYCHANNELAVAILABILITYMODEENUM_CRITERIONCATEGORYCHANNELAVAILABILITYMODE = _descriptor.EnumDescriptor(
  name='CriterionCategoryChannelAvailabilityMode',
  full_name='google.ads.googleads.v0.enums.CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALL_CHANNELS', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHANNEL_TYPE_AND_ALL_SUBTYPES', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHANNEL_TYPE_AND_SUBSET_SUBTYPES', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=171,
  serialized_end=334,
)
_sym_db.RegisterEnumDescriptor(_CRITERIONCATEGORYCHANNELAVAILABILITYMODEENUM_CRITERIONCATEGORYCHANNELAVAILABILITYMODE)


_CRITERIONCATEGORYCHANNELAVAILABILITYMODEENUM = _descriptor.Descriptor(
  name='CriterionCategoryChannelAvailabilityModeEnum',
  full_name='google.ads.googleads.v0.enums.CriterionCategoryChannelAvailabilityModeEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CRITERIONCATEGORYCHANNELAVAILABILITYMODEENUM_CRITERIONCATEGORYCHANNELAVAILABILITYMODE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=122,
  serialized_end=334,
)

_CRITERIONCATEGORYCHANNELAVAILABILITYMODEENUM_CRITERIONCATEGORYCHANNELAVAILABILITYMODE.containing_type = _CRITERIONCATEGORYCHANNELAVAILABILITYMODEENUM
DESCRIPTOR.message_types_by_name['CriterionCategoryChannelAvailabilityModeEnum'] = _CRITERIONCATEGORYCHANNELAVAILABILITYMODEENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CriterionCategoryChannelAvailabilityModeEnum = _reflection.GeneratedProtocolMessageType('CriterionCategoryChannelAvailabilityModeEnum', (_message.Message,), dict(
  DESCRIPTOR = _CRITERIONCATEGORYCHANNELAVAILABILITYMODEENUM,
  __module__ = 'google.ads.google_ads.v0.proto.enums.criterion_category_channel_availability_mode_pb2'
  ,
  __doc__ = """Describes channel availability mode for a criterion availability -
  whether the availability is meant to include all advertising channels,
  or a particular channel with all its channel subtypes, or a channel with
  a certain subset of channel subtypes.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.enums.CriterionCategoryChannelAvailabilityModeEnum)
  ))
_sym_db.RegisterMessage(CriterionCategoryChannelAvailabilityModeEnum)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n!com.google.ads.googleads.v0.enumsB-CriterionCategoryChannelAvailabilityModeProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v0/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V0.Enums\312\002\035Google\\Ads\\GoogleAds\\V0\\Enums'))
# @@protoc_insertion_point(module_scope)
