# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/enums/real_estate_placeholder_field.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/enums/real_estate_placeholder_field.proto',
  package='google.ads.googleads.v0.enums',
  syntax='proto3',
  serialized_pb=_b('\nGgoogle/ads/googleads_v0/proto/enums/real_estate_placeholder_field.proto\x12\x1dgoogle.ads.googleads.v0.enums\"\xa9\x03\n\x1eRealEstatePlaceholderFieldEnum\"\x86\x03\n\x1aRealEstatePlaceholderField\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x0e\n\nLISTING_ID\x10\x02\x12\x10\n\x0cLISTING_NAME\x10\x03\x12\r\n\tCITY_NAME\x10\x04\x12\x0f\n\x0b\x44\x45SCRIPTION\x10\x05\x12\x0b\n\x07\x41\x44\x44RESS\x10\x06\x12\t\n\x05PRICE\x10\x07\x12\x13\n\x0f\x46ORMATTED_PRICE\x10\x08\x12\r\n\tIMAGE_URL\x10\t\x12\x11\n\rPROPERTY_TYPE\x10\n\x12\x10\n\x0cLISTING_TYPE\x10\x0b\x12\x17\n\x13\x43ONTEXTUAL_KEYWORDS\x10\x0c\x12\x0e\n\nFINAL_URLS\x10\r\x12\x15\n\x11\x46INAL_MOBILE_URLS\x10\x0e\x12\x10\n\x0cTRACKING_URL\x10\x0f\x12\x14\n\x10\x41NDROID_APP_LINK\x10\x10\x12\x17\n\x13SIMILAR_LISTING_IDS\x10\x11\x12\x10\n\x0cIOS_APP_LINK\x10\x12\x12\x14\n\x10IOS_APP_STORE_ID\x10\x13\x42\xd0\x01\n!com.google.ads.googleads.v0.enumsB\x1fRealEstatePlaceholderFieldProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v0/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V0.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V0\\Enumsb\x06proto3')
)



_REALESTATEPLACEHOLDERFIELDENUM_REALESTATEPLACEHOLDERFIELD = _descriptor.EnumDescriptor(
  name='RealEstatePlaceholderField',
  full_name='google.ads.googleads.v0.enums.RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LISTING_ID', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LISTING_NAME', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CITY_NAME', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DESCRIPTION', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADDRESS', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRICE', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FORMATTED_PRICE', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMAGE_URL', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROPERTY_TYPE', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LISTING_TYPE', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONTEXTUAL_KEYWORDS', index=12, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINAL_URLS', index=13, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINAL_MOBILE_URLS', index=14, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRACKING_URL', index=15, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ANDROID_APP_LINK', index=16, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SIMILAR_LISTING_IDS', index=17, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IOS_APP_LINK', index=18, number=18,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IOS_APP_STORE_ID', index=19, number=19,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=142,
  serialized_end=532,
)
_sym_db.RegisterEnumDescriptor(_REALESTATEPLACEHOLDERFIELDENUM_REALESTATEPLACEHOLDERFIELD)


_REALESTATEPLACEHOLDERFIELDENUM = _descriptor.Descriptor(
  name='RealEstatePlaceholderFieldEnum',
  full_name='google.ads.googleads.v0.enums.RealEstatePlaceholderFieldEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _REALESTATEPLACEHOLDERFIELDENUM_REALESTATEPLACEHOLDERFIELD,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=107,
  serialized_end=532,
)

_REALESTATEPLACEHOLDERFIELDENUM_REALESTATEPLACEHOLDERFIELD.containing_type = _REALESTATEPLACEHOLDERFIELDENUM
DESCRIPTOR.message_types_by_name['RealEstatePlaceholderFieldEnum'] = _REALESTATEPLACEHOLDERFIELDENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RealEstatePlaceholderFieldEnum = _reflection.GeneratedProtocolMessageType('RealEstatePlaceholderFieldEnum', (_message.Message,), dict(
  DESCRIPTOR = _REALESTATEPLACEHOLDERFIELDENUM,
  __module__ = 'google.ads.google_ads.v0.proto.enums.real_estate_placeholder_field_pb2'
  ,
  __doc__ = """Values for Real Estate placeholder fields. For more information about
  dynamic remarketing feeds, see
  https://support.google.com/google-ads/answer/6053288.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.enums.RealEstatePlaceholderFieldEnum)
  ))
_sym_db.RegisterMessage(RealEstatePlaceholderFieldEnum)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n!com.google.ads.googleads.v0.enumsB\037RealEstatePlaceholderFieldProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v0/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V0.Enums\312\002\035Google\\Ads\\GoogleAds\\V0\\Enums'))
# @@protoc_insertion_point(module_scope)
