# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v0.proto.resources import campaign_group_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__group__pb2
from google.ads.google_ads.v0.proto.services import campaign_group_service_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_campaign__group__service__pb2


class CampaignGroupServiceStub(object):
  """Service to manage campaign groups.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetCampaignGroup = channel.unary_unary(
        '/google.ads.googleads.v0.services.CampaignGroupService/GetCampaignGroup',
        request_serializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_campaign__group__service__pb2.GetCampaignGroupRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__group__pb2.CampaignGroup.FromString,
        )
    self.MutateCampaignGroups = channel.unary_unary(
        '/google.ads.googleads.v0.services.CampaignGroupService/MutateCampaignGroups',
        request_serializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_campaign__group__service__pb2.MutateCampaignGroupsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_campaign__group__service__pb2.MutateCampaignGroupsResponse.FromString,
        )


class CampaignGroupServiceServicer(object):
  """Service to manage campaign groups.
  """

  def GetCampaignGroup(self, request, context):
    """Returns the requested campaign group in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateCampaignGroups(self, request, context):
    """Creates, updates, or removes campaign groups. Operation statuses are
    returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_CampaignGroupServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetCampaignGroup': grpc.unary_unary_rpc_method_handler(
          servicer.GetCampaignGroup,
          request_deserializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_campaign__group__service__pb2.GetCampaignGroupRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__group__pb2.CampaignGroup.SerializeToString,
      ),
      'MutateCampaignGroups': grpc.unary_unary_rpc_method_handler(
          servicer.MutateCampaignGroups,
          request_deserializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_campaign__group__service__pb2.MutateCampaignGroupsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_campaign__group__service__pb2.MutateCampaignGroupsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v0.services.CampaignGroupService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
