# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/services/campaign_feed_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.resources import campaign_feed_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__feed__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/services/campaign_feed_service.proto',
  package='google.ads.googleads.v0.services',
  syntax='proto3',
  serialized_pb=_b('\nBgoogle/ads/googleads_v0/proto/services/campaign_feed_service.proto\x12 google.ads.googleads.v0.services\x1a;google/ads/googleads_v0/proto/resources/campaign_feed.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\"/\n\x16GetCampaignFeedRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"~\n\x1aMutateCampaignFeedsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12K\n\noperations\x18\x02 \x03(\x0b\x32\x37.google.ads.googleads.v0.services.CampaignFeedOperation\"\xed\x01\n\x15\x43\x61mpaignFeedOperation\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x41\n\x06\x63reate\x18\x01 \x01(\x0b\x32/.google.ads.googleads.v0.resources.CampaignFeedH\x00\x12\x41\n\x06update\x18\x02 \x01(\x0b\x32/.google.ads.googleads.v0.resources.CampaignFeedH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"j\n\x1bMutateCampaignFeedsResponse\x12K\n\x07results\x18\x02 \x03(\x0b\x32:.google.ads.googleads.v0.services.MutateCampaignFeedResult\"1\n\x18MutateCampaignFeedResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xa1\x03\n\x13\x43\x61mpaignFeedService\x12\xb5\x01\n\x0fGetCampaignFeed\x12\x38.google.ads.googleads.v0.services.GetCampaignFeedRequest\x1a/.google.ads.googleads.v0.resources.CampaignFeed\"7\x82\xd3\xe4\x93\x02\x31\x12//v0/{resource_name=customers/*/campaignFeeds/*}\x12\xd1\x01\n\x13MutateCampaignFeeds\x12<.google.ads.googleads.v0.services.MutateCampaignFeedsRequest\x1a=.google.ads.googleads.v0.services.MutateCampaignFeedsResponse\"=\x82\xd3\xe4\x93\x02\x37\"2/v0/customers/{customer_id=*}/campaignFeeds:mutate:\x01*B\xd8\x01\n$com.google.ads.googleads.v0.servicesB\x18\x43\x61mpaignFeedServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V0.Services\xca\x02 Google\\Ads\\GoogleAds\\V0\\Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__feed__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,])




_GETCAMPAIGNFEEDREQUEST = _descriptor.Descriptor(
  name='GetCampaignFeedRequest',
  full_name='google.ads.googleads.v0.services.GetCampaignFeedRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.GetCampaignFeedRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=229,
  serialized_end=276,
)


_MUTATECAMPAIGNFEEDSREQUEST = _descriptor.Descriptor(
  name='MutateCampaignFeedsRequest',
  full_name='google.ads.googleads.v0.services.MutateCampaignFeedsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v0.services.MutateCampaignFeedsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v0.services.MutateCampaignFeedsRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=278,
  serialized_end=404,
)


_CAMPAIGNFEEDOPERATION = _descriptor.Descriptor(
  name='CampaignFeedOperation',
  full_name='google.ads.googleads.v0.services.CampaignFeedOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v0.services.CampaignFeedOperation.update_mask', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v0.services.CampaignFeedOperation.create', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v0.services.CampaignFeedOperation.update', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v0.services.CampaignFeedOperation.remove', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v0.services.CampaignFeedOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=407,
  serialized_end=644,
)


_MUTATECAMPAIGNFEEDSRESPONSE = _descriptor.Descriptor(
  name='MutateCampaignFeedsResponse',
  full_name='google.ads.googleads.v0.services.MutateCampaignFeedsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v0.services.MutateCampaignFeedsResponse.results', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=646,
  serialized_end=752,
)


_MUTATECAMPAIGNFEEDRESULT = _descriptor.Descriptor(
  name='MutateCampaignFeedResult',
  full_name='google.ads.googleads.v0.services.MutateCampaignFeedResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.MutateCampaignFeedResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=754,
  serialized_end=803,
)

_MUTATECAMPAIGNFEEDSREQUEST.fields_by_name['operations'].message_type = _CAMPAIGNFEEDOPERATION
_CAMPAIGNFEEDOPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_CAMPAIGNFEEDOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__feed__pb2._CAMPAIGNFEED
_CAMPAIGNFEEDOPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__feed__pb2._CAMPAIGNFEED
_CAMPAIGNFEEDOPERATION.oneofs_by_name['operation'].fields.append(
  _CAMPAIGNFEEDOPERATION.fields_by_name['create'])
_CAMPAIGNFEEDOPERATION.fields_by_name['create'].containing_oneof = _CAMPAIGNFEEDOPERATION.oneofs_by_name['operation']
_CAMPAIGNFEEDOPERATION.oneofs_by_name['operation'].fields.append(
  _CAMPAIGNFEEDOPERATION.fields_by_name['update'])
_CAMPAIGNFEEDOPERATION.fields_by_name['update'].containing_oneof = _CAMPAIGNFEEDOPERATION.oneofs_by_name['operation']
_CAMPAIGNFEEDOPERATION.oneofs_by_name['operation'].fields.append(
  _CAMPAIGNFEEDOPERATION.fields_by_name['remove'])
_CAMPAIGNFEEDOPERATION.fields_by_name['remove'].containing_oneof = _CAMPAIGNFEEDOPERATION.oneofs_by_name['operation']
_MUTATECAMPAIGNFEEDSRESPONSE.fields_by_name['results'].message_type = _MUTATECAMPAIGNFEEDRESULT
DESCRIPTOR.message_types_by_name['GetCampaignFeedRequest'] = _GETCAMPAIGNFEEDREQUEST
DESCRIPTOR.message_types_by_name['MutateCampaignFeedsRequest'] = _MUTATECAMPAIGNFEEDSREQUEST
DESCRIPTOR.message_types_by_name['CampaignFeedOperation'] = _CAMPAIGNFEEDOPERATION
DESCRIPTOR.message_types_by_name['MutateCampaignFeedsResponse'] = _MUTATECAMPAIGNFEEDSRESPONSE
DESCRIPTOR.message_types_by_name['MutateCampaignFeedResult'] = _MUTATECAMPAIGNFEEDRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetCampaignFeedRequest = _reflection.GeneratedProtocolMessageType('GetCampaignFeedRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCAMPAIGNFEEDREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_feed_service_pb2'
  ,
  __doc__ = """Request message for
  [CampaignFeedService.GetCampaignFeed][google.ads.googleads.v0.services.CampaignFeedService.GetCampaignFeed].
  
  
  Attributes:
      resource_name:
          The resource name of the campaign feed to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.GetCampaignFeedRequest)
  ))
_sym_db.RegisterMessage(GetCampaignFeedRequest)

MutateCampaignFeedsRequest = _reflection.GeneratedProtocolMessageType('MutateCampaignFeedsRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECAMPAIGNFEEDSREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_feed_service_pb2'
  ,
  __doc__ = """Request message for
  [CampaignFeedService.MutateCampaignFeeds][google.ads.googleads.v0.services.CampaignFeedService.MutateCampaignFeeds].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose campaign feeds are being
          modified.
      operations:
          The list of operations to perform on individual campaign
          feeds.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateCampaignFeedsRequest)
  ))
_sym_db.RegisterMessage(MutateCampaignFeedsRequest)

CampaignFeedOperation = _reflection.GeneratedProtocolMessageType('CampaignFeedOperation', (_message.Message,), dict(
  DESCRIPTOR = _CAMPAIGNFEEDOPERATION,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_feed_service_pb2'
  ,
  __doc__ = """A single operation (create, update, remove) on a campaign feed.
  
  
  Attributes:
      update_mask:
          FieldMask that determines which resource fields are modified
          in an update.
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          campaign feed.
      update:
          Update operation: The campaign feed is expected to have a
          valid resource name.
      remove:
          Remove operation: A resource name for the removed campaign
          feed is expected, in this format:  ``customers/{customer_id}/c
          ampaignFeeds/{campaign_id}_{feed_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.CampaignFeedOperation)
  ))
_sym_db.RegisterMessage(CampaignFeedOperation)

MutateCampaignFeedsResponse = _reflection.GeneratedProtocolMessageType('MutateCampaignFeedsResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECAMPAIGNFEEDSRESPONSE,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_feed_service_pb2'
  ,
  __doc__ = """Response message for a campaign feed mutate.
  
  
  Attributes:
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateCampaignFeedsResponse)
  ))
_sym_db.RegisterMessage(MutateCampaignFeedsResponse)

MutateCampaignFeedResult = _reflection.GeneratedProtocolMessageType('MutateCampaignFeedResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECAMPAIGNFEEDRESULT,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_feed_service_pb2'
  ,
  __doc__ = """The result for the campaign feed mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateCampaignFeedResult)
  ))
_sym_db.RegisterMessage(MutateCampaignFeedResult)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n$com.google.ads.googleads.v0.servicesB\030CampaignFeedServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V0.Services\312\002 Google\\Ads\\GoogleAds\\V0\\Services'))

_CAMPAIGNFEEDSERVICE = _descriptor.ServiceDescriptor(
  name='CampaignFeedService',
  full_name='google.ads.googleads.v0.services.CampaignFeedService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=806,
  serialized_end=1223,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetCampaignFeed',
    full_name='google.ads.googleads.v0.services.CampaignFeedService.GetCampaignFeed',
    index=0,
    containing_service=None,
    input_type=_GETCAMPAIGNFEEDREQUEST,
    output_type=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__feed__pb2._CAMPAIGNFEED,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0021\022//v0/{resource_name=customers/*/campaignFeeds/*}')),
  ),
  _descriptor.MethodDescriptor(
    name='MutateCampaignFeeds',
    full_name='google.ads.googleads.v0.services.CampaignFeedService.MutateCampaignFeeds',
    index=1,
    containing_service=None,
    input_type=_MUTATECAMPAIGNFEEDSREQUEST,
    output_type=_MUTATECAMPAIGNFEEDSRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0027\"2/v0/customers/{customer_id=*}/campaignFeeds:mutate:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_CAMPAIGNFEEDSERVICE)

DESCRIPTOR.services_by_name['CampaignFeedService'] = _CAMPAIGNFEEDSERVICE

# @@protoc_insertion_point(module_scope)
