# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/services/feed_item_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.resources import feed_item_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_feed__item__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/services/feed_item_service.proto',
  package='google.ads.googleads.v0.services',
  syntax='proto3',
  serialized_pb=_b('\n>google/ads/googleads_v0/proto/services/feed_item_service.proto\x12 google.ads.googleads.v0.services\x1a\x37google/ads/googleads_v0/proto/resources/feed_item.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\"+\n\x12GetFeedItemRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"v\n\x16MutateFeedItemsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12G\n\noperations\x18\x02 \x03(\x0b\x32\x33.google.ads.googleads.v0.services.FeedItemOperation\"\xe1\x01\n\x11\x46\x65\x65\x64ItemOperation\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12=\n\x06\x63reate\x18\x01 \x01(\x0b\x32+.google.ads.googleads.v0.resources.FeedItemH\x00\x12=\n\x06update\x18\x02 \x01(\x0b\x32+.google.ads.googleads.v0.resources.FeedItemH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"b\n\x17MutateFeedItemsResponse\x12G\n\x07results\x18\x02 \x03(\x0b\x32\x36.google.ads.googleads.v0.services.MutateFeedItemResult\"-\n\x14MutateFeedItemResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xfd\x02\n\x0f\x46\x65\x65\x64ItemService\x12\xa5\x01\n\x0bGetFeedItem\x12\x34.google.ads.googleads.v0.services.GetFeedItemRequest\x1a+.google.ads.googleads.v0.resources.FeedItem\"3\x82\xd3\xe4\x93\x02-\x12+/v0/{resource_name=customers/*/feedItems/*}\x12\xc1\x01\n\x0fMutateFeedItems\x12\x38.google.ads.googleads.v0.services.MutateFeedItemsRequest\x1a\x39.google.ads.googleads.v0.services.MutateFeedItemsResponse\"9\x82\xd3\xe4\x93\x02\x33\"./v0/customers/{customer_id=*}/feedItems:mutate:\x01*B\xd4\x01\n$com.google.ads.googleads.v0.servicesB\x14\x46\x65\x65\x64ItemServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V0.Services\xca\x02 Google\\Ads\\GoogleAds\\V0\\Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_feed__item__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,])




_GETFEEDITEMREQUEST = _descriptor.Descriptor(
  name='GetFeedItemRequest',
  full_name='google.ads.googleads.v0.services.GetFeedItemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.GetFeedItemRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=264,
)


_MUTATEFEEDITEMSREQUEST = _descriptor.Descriptor(
  name='MutateFeedItemsRequest',
  full_name='google.ads.googleads.v0.services.MutateFeedItemsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v0.services.MutateFeedItemsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v0.services.MutateFeedItemsRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=266,
  serialized_end=384,
)


_FEEDITEMOPERATION = _descriptor.Descriptor(
  name='FeedItemOperation',
  full_name='google.ads.googleads.v0.services.FeedItemOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v0.services.FeedItemOperation.update_mask', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v0.services.FeedItemOperation.create', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v0.services.FeedItemOperation.update', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v0.services.FeedItemOperation.remove', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v0.services.FeedItemOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=387,
  serialized_end=612,
)


_MUTATEFEEDITEMSRESPONSE = _descriptor.Descriptor(
  name='MutateFeedItemsResponse',
  full_name='google.ads.googleads.v0.services.MutateFeedItemsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v0.services.MutateFeedItemsResponse.results', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=614,
  serialized_end=712,
)


_MUTATEFEEDITEMRESULT = _descriptor.Descriptor(
  name='MutateFeedItemResult',
  full_name='google.ads.googleads.v0.services.MutateFeedItemResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.MutateFeedItemResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=714,
  serialized_end=759,
)

_MUTATEFEEDITEMSREQUEST.fields_by_name['operations'].message_type = _FEEDITEMOPERATION
_FEEDITEMOPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_FEEDITEMOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_feed__item__pb2._FEEDITEM
_FEEDITEMOPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_feed__item__pb2._FEEDITEM
_FEEDITEMOPERATION.oneofs_by_name['operation'].fields.append(
  _FEEDITEMOPERATION.fields_by_name['create'])
_FEEDITEMOPERATION.fields_by_name['create'].containing_oneof = _FEEDITEMOPERATION.oneofs_by_name['operation']
_FEEDITEMOPERATION.oneofs_by_name['operation'].fields.append(
  _FEEDITEMOPERATION.fields_by_name['update'])
_FEEDITEMOPERATION.fields_by_name['update'].containing_oneof = _FEEDITEMOPERATION.oneofs_by_name['operation']
_FEEDITEMOPERATION.oneofs_by_name['operation'].fields.append(
  _FEEDITEMOPERATION.fields_by_name['remove'])
_FEEDITEMOPERATION.fields_by_name['remove'].containing_oneof = _FEEDITEMOPERATION.oneofs_by_name['operation']
_MUTATEFEEDITEMSRESPONSE.fields_by_name['results'].message_type = _MUTATEFEEDITEMRESULT
DESCRIPTOR.message_types_by_name['GetFeedItemRequest'] = _GETFEEDITEMREQUEST
DESCRIPTOR.message_types_by_name['MutateFeedItemsRequest'] = _MUTATEFEEDITEMSREQUEST
DESCRIPTOR.message_types_by_name['FeedItemOperation'] = _FEEDITEMOPERATION
DESCRIPTOR.message_types_by_name['MutateFeedItemsResponse'] = _MUTATEFEEDITEMSRESPONSE
DESCRIPTOR.message_types_by_name['MutateFeedItemResult'] = _MUTATEFEEDITEMRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetFeedItemRequest = _reflection.GeneratedProtocolMessageType('GetFeedItemRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETFEEDITEMREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.feed_item_service_pb2'
  ,
  __doc__ = """Request message for
  [FeedItemService.GetFeedItem][google.ads.googleads.v0.services.FeedItemService.GetFeedItem].
  
  
  Attributes:
      resource_name:
          The resource name of the feed item to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.GetFeedItemRequest)
  ))
_sym_db.RegisterMessage(GetFeedItemRequest)

MutateFeedItemsRequest = _reflection.GeneratedProtocolMessageType('MutateFeedItemsRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEFEEDITEMSREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.feed_item_service_pb2'
  ,
  __doc__ = """Request message for
  [FeedItemService.MutateFeedItems][google.ads.googleads.v0.services.FeedItemService.MutateFeedItems].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose feed items are being modified.
      operations:
          The list of operations to perform on individual feed items.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateFeedItemsRequest)
  ))
_sym_db.RegisterMessage(MutateFeedItemsRequest)

FeedItemOperation = _reflection.GeneratedProtocolMessageType('FeedItemOperation', (_message.Message,), dict(
  DESCRIPTOR = _FEEDITEMOPERATION,
  __module__ = 'google.ads.google_ads.v0.proto.services.feed_item_service_pb2'
  ,
  __doc__ = """A single operation (create, update, remove) on an feed item.
  
  
  Attributes:
      update_mask:
          FieldMask that determines which resource fields are modified
          in an update.
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          feed item.
      update:
          Update operation: The feed item is expected to have a valid
          resource name.
      remove:
          Remove operation: A resource name for the removed feed item is
          expected, in this format:
          ``customers/{customer_id}/feedItems/{feed_id}_{feed_item_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.FeedItemOperation)
  ))
_sym_db.RegisterMessage(FeedItemOperation)

MutateFeedItemsResponse = _reflection.GeneratedProtocolMessageType('MutateFeedItemsResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEFEEDITEMSRESPONSE,
  __module__ = 'google.ads.google_ads.v0.proto.services.feed_item_service_pb2'
  ,
  __doc__ = """Response message for an feed item mutate.
  
  
  Attributes:
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateFeedItemsResponse)
  ))
_sym_db.RegisterMessage(MutateFeedItemsResponse)

MutateFeedItemResult = _reflection.GeneratedProtocolMessageType('MutateFeedItemResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEFEEDITEMRESULT,
  __module__ = 'google.ads.google_ads.v0.proto.services.feed_item_service_pb2'
  ,
  __doc__ = """The result for the feed item mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateFeedItemResult)
  ))
_sym_db.RegisterMessage(MutateFeedItemResult)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n$com.google.ads.googleads.v0.servicesB\024FeedItemServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V0.Services\312\002 Google\\Ads\\GoogleAds\\V0\\Services'))

_FEEDITEMSERVICE = _descriptor.ServiceDescriptor(
  name='FeedItemService',
  full_name='google.ads.googleads.v0.services.FeedItemService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=762,
  serialized_end=1143,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetFeedItem',
    full_name='google.ads.googleads.v0.services.FeedItemService.GetFeedItem',
    index=0,
    containing_service=None,
    input_type=_GETFEEDITEMREQUEST,
    output_type=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_feed__item__pb2._FEEDITEM,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002-\022+/v0/{resource_name=customers/*/feedItems/*}')),
  ),
  _descriptor.MethodDescriptor(
    name='MutateFeedItems',
    full_name='google.ads.googleads.v0.services.FeedItemService.MutateFeedItems',
    index=1,
    containing_service=None,
    input_type=_MUTATEFEEDITEMSREQUEST,
    output_type=_MUTATEFEEDITEMSRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0023\"./v0/customers/{customer_id=*}/feedItems:mutate:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_FEEDITEMSERVICE)

DESCRIPTOR.services_by_name['FeedItemService'] = _FEEDITEMSERVICE

# @@protoc_insertion_point(module_scope)
