# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/resources/keyword_plan_negative_keyword.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.enums import keyword_match_type_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_keyword__match__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/resources/keyword_plan_negative_keyword.proto',
  package='google.ads.googleads.v0.resources',
  syntax='proto3',
  serialized_pb=_b('\nKgoogle/ads/googleads_v0/proto/resources/keyword_plan_negative_keyword.proto\x12!google.ads.googleads.v0.resources\x1a<google/ads/googleads_v0/proto/enums/keyword_match_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x9f\x02\n\x1aKeywordPlanNegativeKeyword\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12;\n\x15keyword_plan_campaign\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\'\n\x02id\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12*\n\x04text\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12X\n\nmatch_type\x18\x05 \x01(\x0e\x32\x44.google.ads.googleads.v0.enums.KeywordMatchTypeEnum.KeywordMatchTypeB\xe4\x01\n%com.google.ads.googleads.v0.resourcesB\x1fKeywordPlanNegativeKeywordProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v0/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V0.Resources\xca\x02!Google\\Ads\\GoogleAds\\V0\\Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_keyword__match__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])




_KEYWORDPLANNEGATIVEKEYWORD = _descriptor.Descriptor(
  name='KeywordPlanNegativeKeyword',
  full_name='google.ads.googleads.v0.resources.KeywordPlanNegativeKeyword',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.resources.KeywordPlanNegativeKeyword.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_plan_campaign', full_name='google.ads.googleads.v0.resources.KeywordPlanNegativeKeyword.keyword_plan_campaign', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v0.resources.KeywordPlanNegativeKeyword.id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text', full_name='google.ads.googleads.v0.resources.KeywordPlanNegativeKeyword.text', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_type', full_name='google.ads.googleads.v0.resources.KeywordPlanNegativeKeyword.match_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=209,
  serialized_end=496,
)

_KEYWORDPLANNEGATIVEKEYWORD.fields_by_name['keyword_plan_campaign'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_KEYWORDPLANNEGATIVEKEYWORD.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_KEYWORDPLANNEGATIVEKEYWORD.fields_by_name['text'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_KEYWORDPLANNEGATIVEKEYWORD.fields_by_name['match_type'].enum_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_keyword__match__type__pb2._KEYWORDMATCHTYPEENUM_KEYWORDMATCHTYPE
DESCRIPTOR.message_types_by_name['KeywordPlanNegativeKeyword'] = _KEYWORDPLANNEGATIVEKEYWORD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KeywordPlanNegativeKeyword = _reflection.GeneratedProtocolMessageType('KeywordPlanNegativeKeyword', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDPLANNEGATIVEKEYWORD,
  __module__ = 'google.ads.google_ads.v0.proto.resources.keyword_plan_negative_keyword_pb2'
  ,
  __doc__ = """A Keyword Plan negative keyword.
  
  
  Attributes:
      resource_name:
          The resource name of the Keyword Plan negative keyword.
          KeywordPlanNegativeKeyword resource names have the form:  ``cu
          stomers/{customer_id}/keywordPlanNegativeKeywords/{kp_negative
          _keyword_id}``
      keyword_plan_campaign:
          The Keyword Plan campaign to which this negative keyword
          belongs.
      id:
          The ID of the Keyword Plan negative keyword.
      text:
          The keyword text.
      match_type:
          The keyword match type.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.resources.KeywordPlanNegativeKeyword)
  ))
_sym_db.RegisterMessage(KeywordPlanNegativeKeyword)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n%com.google.ads.googleads.v0.resourcesB\037KeywordPlanNegativeKeywordProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v0/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V0.Resources\312\002!Google\\Ads\\GoogleAds\\V0\\Resources'))
# @@protoc_insertion_point(module_scope)
