# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/common/user_lists.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.enums import customer_match_upload_key_type_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_customer__match__upload__key__type__pb2
from google.ads.google_ads.v0.proto.enums import user_list_crm_data_source_type_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_user__list__crm__data__source__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/common/user_lists.proto',
  package='google.ads.googleads.v0.common',
  syntax='proto3',
  serialized_pb=_b('\n5google/ads/googleads_v0/proto/common/user_lists.proto\x12\x1egoogle.ads.googleads.v0.common\x1aHgoogle/ads/googleads_v0/proto/enums/customer_match_upload_key_type.proto\x1aHgoogle/ads/googleads_v0/proto/enums/user_list_crm_data_source_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\"K\n\x13SimilarUserListInfo\x12\x34\n\x0eseed_user_list\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xa9\x02\n\x14\x43rmBasedUserListInfo\x12,\n\x06\x61pp_id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12q\n\x0fupload_key_type\x18\x02 \x01(\x0e\x32X.google.ads.googleads.v0.enums.CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyType\x12p\n\x10\x64\x61ta_source_type\x18\x03 \x01(\x0e\x32V.google.ads.googleads.v0.enums.UserListCrmDataSourceTypeEnum.UserListCrmDataSourceTypeB\xc4\x01\n\"com.google.ads.googleads.v0.commonB\x0eUserListsProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v0/common;common\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V0.Common\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V0\\Commonb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_customer__match__upload__key__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_user__list__crm__data__source__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])




_SIMILARUSERLISTINFO = _descriptor.Descriptor(
  name='SimilarUserListInfo',
  full_name='google.ads.googleads.v0.common.SimilarUserListInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='seed_user_list', full_name='google.ads.googleads.v0.common.SimilarUserListInfo.seed_user_list', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=269,
  serialized_end=344,
)


_CRMBASEDUSERLISTINFO = _descriptor.Descriptor(
  name='CrmBasedUserListInfo',
  full_name='google.ads.googleads.v0.common.CrmBasedUserListInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='google.ads.googleads.v0.common.CrmBasedUserListInfo.app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upload_key_type', full_name='google.ads.googleads.v0.common.CrmBasedUserListInfo.upload_key_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_source_type', full_name='google.ads.googleads.v0.common.CrmBasedUserListInfo.data_source_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=347,
  serialized_end=644,
)

_SIMILARUSERLISTINFO.fields_by_name['seed_user_list'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CRMBASEDUSERLISTINFO.fields_by_name['app_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CRMBASEDUSERLISTINFO.fields_by_name['upload_key_type'].enum_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_customer__match__upload__key__type__pb2._CUSTOMERMATCHUPLOADKEYTYPEENUM_CUSTOMERMATCHUPLOADKEYTYPE
_CRMBASEDUSERLISTINFO.fields_by_name['data_source_type'].enum_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_user__list__crm__data__source__type__pb2._USERLISTCRMDATASOURCETYPEENUM_USERLISTCRMDATASOURCETYPE
DESCRIPTOR.message_types_by_name['SimilarUserListInfo'] = _SIMILARUSERLISTINFO
DESCRIPTOR.message_types_by_name['CrmBasedUserListInfo'] = _CRMBASEDUSERLISTINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SimilarUserListInfo = _reflection.GeneratedProtocolMessageType('SimilarUserListInfo', (_message.Message,), dict(
  DESCRIPTOR = _SIMILARUSERLISTINFO,
  __module__ = 'google.ads.google_ads.v0.proto.common.user_lists_pb2'
  ,
  __doc__ = """SimilarUserList is a list of users which are similar to users from
  another UserList. These lists are read-only and automatically created by
  Google.
  
  
  Attributes:
      seed_user_list:
          Seed UserList from which this list is derived.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.common.SimilarUserListInfo)
  ))
_sym_db.RegisterMessage(SimilarUserListInfo)

CrmBasedUserListInfo = _reflection.GeneratedProtocolMessageType('CrmBasedUserListInfo', (_message.Message,), dict(
  DESCRIPTOR = _CRMBASEDUSERLISTINFO,
  __module__ = 'google.ads.google_ads.v0.proto.common.user_lists_pb2'
  ,
  __doc__ = """UserList of CRM users provided by the advertiser.
  
  
  Attributes:
      app_id:
          A string that uniquely identifies a mobile application from
          which the data was collected to the Google Ads API. For iOS,
          the ID string is the 9 digit string that appears at the end of
          an App Store URL (e.g., "476943146" for "Flood-It! 2" whose
          App Store link is http://itunes.apple.com/us/app/flood-
          it!-2/id476943146). For Android, the ID string is the
          application's package name (e.g., "com.labpixies.colordrips"
          for "Color Drips" given Google Play link https://play.google.c
          om/store/apps/details?id=com.labpixies.colordrips). Required
          when creating CrmBasedUserList for uploading mobile
          advertising IDs.
      upload_key_type:
          Matching key type of the list. Mixed data types are not
          allowed on the same list. This field is required for an ADD
          operation.
      data_source_type:
          Data source of the list. Default value is FIRST\_PARTY. Only
          whitelisted customers can create third party sourced crm
          lists.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.common.CrmBasedUserListInfo)
  ))
_sym_db.RegisterMessage(CrmBasedUserListInfo)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\"com.google.ads.googleads.v0.commonB\016UserListsProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v0/common;common\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V0.Common\312\002\036Google\\Ads\\GoogleAds\\V0\\Common'))
# @@protoc_insertion_point(module_scope)
